**Example 1: 重命名云数据库实例**



Input: 

```
tccli mongodb RenameInstance --cli-unfold-argument  \
    --InstanceId cmgo-eqmoa5sf \
    --NewName test_name
```

Output: 
```
{
    "Response": {
        "RequestId": "8e2a339e-5ba9-4da3-8dc2-65a0a6314811"
    }
}
```

